Enum awc::error::SendRequestError
source · [−]#[non_exhaustive]
pub enum SendRequestError {
Url(InvalidUrl),
Connect(ConnectError),
Send(Error),
Response(ParseError),
Http(HttpError),
H2(Error),
Timeout,
TunnelNotSupported,
Body(Box<dyn Error>),
Custom(Box<dyn Error>, Box<dyn Debug>),
}Expand description
A set of errors that can occur during request sending and response reading
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Url(InvalidUrl)
Invalid URL
Connect(ConnectError)
Failed to connect to host
Send(Error)
Error sending request
Response(ParseError)
Error parsing response
Http(HttpError)
Http error
H2(Error)
Http2 error
Timeout
Response took too long
TunnelNotSupported
Tunnels are not supported for HTTP/2 connection
Body(Box<dyn Error>)
Error sending request body
Custom(Box<dyn Error>, Box<dyn Debug>)
Other errors that can occur after submitting a request.